# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.math_element import MathElement

class BorderBoxElement(MathElement):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'base': 'MathElement',
        'hide_top': 'bool',
        'hide_bottom': 'bool',
        'hide_left': 'bool',
        'hide_right': 'bool',
        'strikethrough_horizontal': 'bool',
        'strikethrough_vertical': 'bool',
        'strikethrough_bottom_left_to_top_right': 'bool',
        'strikethrough_top_left_to_bottom_right': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'base': 'base',
        'hide_top': 'hideTop',
        'hide_bottom': 'hideBottom',
        'hide_left': 'hideLeft',
        'hide_right': 'hideRight',
        'strikethrough_horizontal': 'strikethroughHorizontal',
        'strikethrough_vertical': 'strikethroughVertical',
        'strikethrough_bottom_left_to_top_right': 'strikethroughBottomLeftToTopRight',
        'strikethrough_top_left_to_bottom_right': 'strikethroughTopLeftToBottomRight'
    }

    type_determiners = {
        'type': 'BorderBox',
    }

    def __init__(self, type='BorderBox', base=None, hide_top=None, hide_bottom=None, hide_left=None, hide_right=None, strikethrough_horizontal=None, strikethrough_vertical=None, strikethrough_bottom_left_to_top_right=None, strikethrough_top_left_to_bottom_right=None):  # noqa: E501
        """BorderBoxElement - a model defined in Swagger"""  # noqa: E501
        super(BorderBoxElement, self).__init__(type)

        self._base = None
        self._hide_top = None
        self._hide_bottom = None
        self._hide_left = None
        self._hide_right = None
        self._strikethrough_horizontal = None
        self._strikethrough_vertical = None
        self._strikethrough_bottom_left_to_top_right = None
        self._strikethrough_top_left_to_bottom_right = None
        self.type = 'BorderBox'

        if base is not None:
            self.base = base
        if hide_top is not None:
            self.hide_top = hide_top
        if hide_bottom is not None:
            self.hide_bottom = hide_bottom
        if hide_left is not None:
            self.hide_left = hide_left
        if hide_right is not None:
            self.hide_right = hide_right
        if strikethrough_horizontal is not None:
            self.strikethrough_horizontal = strikethrough_horizontal
        if strikethrough_vertical is not None:
            self.strikethrough_vertical = strikethrough_vertical
        if strikethrough_bottom_left_to_top_right is not None:
            self.strikethrough_bottom_left_to_top_right = strikethrough_bottom_left_to_top_right
        if strikethrough_top_left_to_bottom_right is not None:
            self.strikethrough_top_left_to_bottom_right = strikethrough_top_left_to_bottom_right

    @property
    def base(self):
        """Gets the base of this BorderBoxElement.  # noqa: E501

        Base  # noqa: E501

        :return: The base of this BorderBoxElement.  # noqa: E501
        :rtype: MathElement
        """
        return self._base

    @base.setter
    def base(self, base):
        """Sets the base of this BorderBoxElement.

        Base  # noqa: E501

        :param base: The base of this BorderBoxElement.  # noqa: E501
        :type: MathElement
        """
        self._base = base

    @property
    def hide_top(self):
        """Gets the hide_top of this BorderBoxElement.  # noqa: E501

        Hide Top Edge  # noqa: E501

        :return: The hide_top of this BorderBoxElement.  # noqa: E501
        :rtype: bool
        """
        return self._hide_top

    @hide_top.setter
    def hide_top(self, hide_top):
        """Sets the hide_top of this BorderBoxElement.

        Hide Top Edge  # noqa: E501

        :param hide_top: The hide_top of this BorderBoxElement.  # noqa: E501
        :type: bool
        """
        self._hide_top = hide_top

    @property
    def hide_bottom(self):
        """Gets the hide_bottom of this BorderBoxElement.  # noqa: E501

        Hide Bottom Edge  # noqa: E501

        :return: The hide_bottom of this BorderBoxElement.  # noqa: E501
        :rtype: bool
        """
        return self._hide_bottom

    @hide_bottom.setter
    def hide_bottom(self, hide_bottom):
        """Sets the hide_bottom of this BorderBoxElement.

        Hide Bottom Edge  # noqa: E501

        :param hide_bottom: The hide_bottom of this BorderBoxElement.  # noqa: E501
        :type: bool
        """
        self._hide_bottom = hide_bottom

    @property
    def hide_left(self):
        """Gets the hide_left of this BorderBoxElement.  # noqa: E501

        Hide Left Edge  # noqa: E501

        :return: The hide_left of this BorderBoxElement.  # noqa: E501
        :rtype: bool
        """
        return self._hide_left

    @hide_left.setter
    def hide_left(self, hide_left):
        """Sets the hide_left of this BorderBoxElement.

        Hide Left Edge  # noqa: E501

        :param hide_left: The hide_left of this BorderBoxElement.  # noqa: E501
        :type: bool
        """
        self._hide_left = hide_left

    @property
    def hide_right(self):
        """Gets the hide_right of this BorderBoxElement.  # noqa: E501

        Hide Right Edge  # noqa: E501

        :return: The hide_right of this BorderBoxElement.  # noqa: E501
        :rtype: bool
        """
        return self._hide_right

    @hide_right.setter
    def hide_right(self, hide_right):
        """Sets the hide_right of this BorderBoxElement.

        Hide Right Edge  # noqa: E501

        :param hide_right: The hide_right of this BorderBoxElement.  # noqa: E501
        :type: bool
        """
        self._hide_right = hide_right

    @property
    def strikethrough_horizontal(self):
        """Gets the strikethrough_horizontal of this BorderBoxElement.  # noqa: E501

        Strikethrough Horizontal  # noqa: E501

        :return: The strikethrough_horizontal of this BorderBoxElement.  # noqa: E501
        :rtype: bool
        """
        return self._strikethrough_horizontal

    @strikethrough_horizontal.setter
    def strikethrough_horizontal(self, strikethrough_horizontal):
        """Sets the strikethrough_horizontal of this BorderBoxElement.

        Strikethrough Horizontal  # noqa: E501

        :param strikethrough_horizontal: The strikethrough_horizontal of this BorderBoxElement.  # noqa: E501
        :type: bool
        """
        self._strikethrough_horizontal = strikethrough_horizontal

    @property
    def strikethrough_vertical(self):
        """Gets the strikethrough_vertical of this BorderBoxElement.  # noqa: E501

        Strikethrough Vertical  # noqa: E501

        :return: The strikethrough_vertical of this BorderBoxElement.  # noqa: E501
        :rtype: bool
        """
        return self._strikethrough_vertical

    @strikethrough_vertical.setter
    def strikethrough_vertical(self, strikethrough_vertical):
        """Sets the strikethrough_vertical of this BorderBoxElement.

        Strikethrough Vertical  # noqa: E501

        :param strikethrough_vertical: The strikethrough_vertical of this BorderBoxElement.  # noqa: E501
        :type: bool
        """
        self._strikethrough_vertical = strikethrough_vertical

    @property
    def strikethrough_bottom_left_to_top_right(self):
        """Gets the strikethrough_bottom_left_to_top_right of this BorderBoxElement.  # noqa: E501

        Strikethrough Bottom-Left to Top-Right  # noqa: E501

        :return: The strikethrough_bottom_left_to_top_right of this BorderBoxElement.  # noqa: E501
        :rtype: bool
        """
        return self._strikethrough_bottom_left_to_top_right

    @strikethrough_bottom_left_to_top_right.setter
    def strikethrough_bottom_left_to_top_right(self, strikethrough_bottom_left_to_top_right):
        """Sets the strikethrough_bottom_left_to_top_right of this BorderBoxElement.

        Strikethrough Bottom-Left to Top-Right  # noqa: E501

        :param strikethrough_bottom_left_to_top_right: The strikethrough_bottom_left_to_top_right of this BorderBoxElement.  # noqa: E501
        :type: bool
        """
        self._strikethrough_bottom_left_to_top_right = strikethrough_bottom_left_to_top_right

    @property
    def strikethrough_top_left_to_bottom_right(self):
        """Gets the strikethrough_top_left_to_bottom_right of this BorderBoxElement.  # noqa: E501

        Strikethrough Top-Left to Bottom-Right.  # noqa: E501

        :return: The strikethrough_top_left_to_bottom_right of this BorderBoxElement.  # noqa: E501
        :rtype: bool
        """
        return self._strikethrough_top_left_to_bottom_right

    @strikethrough_top_left_to_bottom_right.setter
    def strikethrough_top_left_to_bottom_right(self, strikethrough_top_left_to_bottom_right):
        """Sets the strikethrough_top_left_to_bottom_right of this BorderBoxElement.

        Strikethrough Top-Left to Bottom-Right.  # noqa: E501

        :param strikethrough_top_left_to_bottom_right: The strikethrough_top_left_to_bottom_right of this BorderBoxElement.  # noqa: E501
        :type: bool
        """
        self._strikethrough_top_left_to_bottom_right = strikethrough_top_left_to_bottom_right

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BorderBoxElement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class AccessPermissions(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'print_document': 'bool',
        'modify_content': 'bool',
        'copy_text_and_graphics': 'bool',
        'add_or_modify_fields': 'bool',
        'fill_existing_fields': 'bool',
        'extract_text_and_graphics': 'bool',
        'assemble_document': 'bool',
        'high_quality_print': 'bool'
    }

    attribute_map = {
        'print_document': 'printDocument',
        'modify_content': 'modifyContent',
        'copy_text_and_graphics': 'copyTextAndGraphics',
        'add_or_modify_fields': 'addOrModifyFields',
        'fill_existing_fields': 'fillExistingFields',
        'extract_text_and_graphics': 'extractTextAndGraphics',
        'assemble_document': 'assembleDocument',
        'high_quality_print': 'highQualityPrint'
    }

    type_determiners = {
    }

    def __init__(self, print_document=None, modify_content=None, copy_text_and_graphics=None, add_or_modify_fields=None, fill_existing_fields=None, extract_text_and_graphics=None, assemble_document=None, high_quality_print=None):  # noqa: E501
        """AccessPermissions - a model defined in Swagger"""  # noqa: E501

        self._print_document = None
        self._modify_content = None
        self._copy_text_and_graphics = None
        self._add_or_modify_fields = None
        self._fill_existing_fields = None
        self._extract_text_and_graphics = None
        self._assemble_document = None
        self._high_quality_print = None

        self.print_document = print_document
        self.modify_content = modify_content
        self.copy_text_and_graphics = copy_text_and_graphics
        self.add_or_modify_fields = add_or_modify_fields
        self.fill_existing_fields = fill_existing_fields
        self.extract_text_and_graphics = extract_text_and_graphics
        self.assemble_document = assemble_document
        self.high_quality_print = high_quality_print

    @property
    def print_document(self):
        """Gets the print_document of this AccessPermissions.  # noqa: E501

        The user may print the document (possibly not at the highest quality level, depending on whether bit HighQualityPrint is also set).  # noqa: E501

        :return: The print_document of this AccessPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._print_document

    @print_document.setter
    def print_document(self, print_document):
        """Sets the print_document of this AccessPermissions.

        The user may print the document (possibly not at the highest quality level, depending on whether bit HighQualityPrint is also set).  # noqa: E501

        :param print_document: The print_document of this AccessPermissions.  # noqa: E501
        :type: bool
        """
        self._print_document = print_document

    @property
    def modify_content(self):
        """Gets the modify_content of this AccessPermissions.  # noqa: E501

        The user may modify the contents of the document by operations other than those controlled by bits AddOrModifyFields, FillExistingFields, AssembleDocument.  # noqa: E501

        :return: The modify_content of this AccessPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._modify_content

    @modify_content.setter
    def modify_content(self, modify_content):
        """Sets the modify_content of this AccessPermissions.

        The user may modify the contents of the document by operations other than those controlled by bits AddOrModifyFields, FillExistingFields, AssembleDocument.  # noqa: E501

        :param modify_content: The modify_content of this AccessPermissions.  # noqa: E501
        :type: bool
        """
        self._modify_content = modify_content

    @property
    def copy_text_and_graphics(self):
        """Gets the copy_text_and_graphics of this AccessPermissions.  # noqa: E501

        The user may copy or otherwise extract text and graphics from the document by operations other than that controlled by bit ExtractTextAndGraphics.  # noqa: E501

        :return: The copy_text_and_graphics of this AccessPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._copy_text_and_graphics

    @copy_text_and_graphics.setter
    def copy_text_and_graphics(self, copy_text_and_graphics):
        """Sets the copy_text_and_graphics of this AccessPermissions.

        The user may copy or otherwise extract text and graphics from the document by operations other than that controlled by bit ExtractTextAndGraphics.  # noqa: E501

        :param copy_text_and_graphics: The copy_text_and_graphics of this AccessPermissions.  # noqa: E501
        :type: bool
        """
        self._copy_text_and_graphics = copy_text_and_graphics

    @property
    def add_or_modify_fields(self):
        """Gets the add_or_modify_fields of this AccessPermissions.  # noqa: E501

        The user may add or modify text annotations, fill in interactive form fields, and, if bit ModifyContent is also set, create or modify interactive form fields (including signature fields).  # noqa: E501

        :return: The add_or_modify_fields of this AccessPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._add_or_modify_fields

    @add_or_modify_fields.setter
    def add_or_modify_fields(self, add_or_modify_fields):
        """Sets the add_or_modify_fields of this AccessPermissions.

        The user may add or modify text annotations, fill in interactive form fields, and, if bit ModifyContent is also set, create or modify interactive form fields (including signature fields).  # noqa: E501

        :param add_or_modify_fields: The add_or_modify_fields of this AccessPermissions.  # noqa: E501
        :type: bool
        """
        self._add_or_modify_fields = add_or_modify_fields

    @property
    def fill_existing_fields(self):
        """Gets the fill_existing_fields of this AccessPermissions.  # noqa: E501

        The user may fill in existing interactive form fields (including signature fields), even if bit AddOrModifyFields is clear.  # noqa: E501

        :return: The fill_existing_fields of this AccessPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._fill_existing_fields

    @fill_existing_fields.setter
    def fill_existing_fields(self, fill_existing_fields):
        """Sets the fill_existing_fields of this AccessPermissions.

        The user may fill in existing interactive form fields (including signature fields), even if bit AddOrModifyFields is clear.  # noqa: E501

        :param fill_existing_fields: The fill_existing_fields of this AccessPermissions.  # noqa: E501
        :type: bool
        """
        self._fill_existing_fields = fill_existing_fields

    @property
    def extract_text_and_graphics(self):
        """Gets the extract_text_and_graphics of this AccessPermissions.  # noqa: E501

        The user may extract text and graphics in support of accessibility to users with disabilities or for other purposes.  # noqa: E501

        :return: The extract_text_and_graphics of this AccessPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._extract_text_and_graphics

    @extract_text_and_graphics.setter
    def extract_text_and_graphics(self, extract_text_and_graphics):
        """Sets the extract_text_and_graphics of this AccessPermissions.

        The user may extract text and graphics in support of accessibility to users with disabilities or for other purposes.  # noqa: E501

        :param extract_text_and_graphics: The extract_text_and_graphics of this AccessPermissions.  # noqa: E501
        :type: bool
        """
        self._extract_text_and_graphics = extract_text_and_graphics

    @property
    def assemble_document(self):
        """Gets the assemble_document of this AccessPermissions.  # noqa: E501

        The user may assemble the document (insert, rotate, or delete pages and create bookmarks or thumbnail images), even if bit ModifyContent is clear.  # noqa: E501

        :return: The assemble_document of this AccessPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._assemble_document

    @assemble_document.setter
    def assemble_document(self, assemble_document):
        """Sets the assemble_document of this AccessPermissions.

        The user may assemble the document (insert, rotate, or delete pages and create bookmarks or thumbnail images), even if bit ModifyContent is clear.  # noqa: E501

        :param assemble_document: The assemble_document of this AccessPermissions.  # noqa: E501
        :type: bool
        """
        self._assemble_document = assemble_document

    @property
    def high_quality_print(self):
        """Gets the high_quality_print of this AccessPermissions.  # noqa: E501

        The user may print the document to a representation from which a faithful digital copy of the PDF content could be generated. When this bit is clear (and bit PrintDocument is set), printing is limited to a low-level representation of the appearance, possibly of degraded quality.  # noqa: E501

        :return: The high_quality_print of this AccessPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._high_quality_print

    @high_quality_print.setter
    def high_quality_print(self, high_quality_print):
        """Sets the high_quality_print of this AccessPermissions.

        The user may print the document to a representation from which a faithful digital copy of the PDF content could be generated. When this bit is clear (and bit PrintDocument is set), printing is limited to a low-level representation of the appearance, possibly of degraded quality.  # noqa: E501

        :param high_quality_print: The high_quality_print of this AccessPermissions.  # noqa: E501
        :type: bool
        """
        self._high_quality_print = high_quality_print

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccessPermissions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.resource_base import ResourceBase

class ProtectionProperties(ResourceBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'encrypt_document_properties': 'bool',
        'read_only_recommended': 'bool',
        'read_password': 'str',
        'write_password': 'str',
        'is_write_protected': 'bool',
        'is_encrypted': 'bool'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'encrypt_document_properties': 'encryptDocumentProperties',
        'read_only_recommended': 'readOnlyRecommended',
        'read_password': 'readPassword',
        'write_password': 'writePassword',
        'is_write_protected': 'isWriteProtected',
        'is_encrypted': 'isEncrypted'
    }

    type_determiners = {
    }

    def __init__(self, self_uri=None, alternate_links=None, encrypt_document_properties=None, read_only_recommended=None, read_password=None, write_password=None, is_write_protected=None, is_encrypted=None):  # noqa: E501
        """ProtectionProperties - a model defined in Swagger"""  # noqa: E501
        super(ProtectionProperties, self).__init__(self_uri, alternate_links)

        self._encrypt_document_properties = None
        self._read_only_recommended = None
        self._read_password = None
        self._write_password = None
        self._is_write_protected = None
        self._is_encrypted = None

        if encrypt_document_properties is not None:
            self.encrypt_document_properties = encrypt_document_properties
        if read_only_recommended is not None:
            self.read_only_recommended = read_only_recommended
        if read_password is not None:
            self.read_password = read_password
        if write_password is not None:
            self.write_password = write_password
        self.is_write_protected = is_write_protected
        self.is_encrypted = is_encrypted

    @property
    def encrypt_document_properties(self):
        """Gets the encrypt_document_properties of this ProtectionProperties.  # noqa: E501

        True if document properties are encrypted. Has effect only for password protected presentations.  # noqa: E501

        :return: The encrypt_document_properties of this ProtectionProperties.  # noqa: E501
        :rtype: bool
        """
        return self._encrypt_document_properties

    @encrypt_document_properties.setter
    def encrypt_document_properties(self, encrypt_document_properties):
        """Sets the encrypt_document_properties of this ProtectionProperties.

        True if document properties are encrypted. Has effect only for password protected presentations.  # noqa: E501

        :param encrypt_document_properties: The encrypt_document_properties of this ProtectionProperties.  # noqa: E501
        :type: bool
        """
        self._encrypt_document_properties = encrypt_document_properties

    @property
    def read_only_recommended(self):
        """Gets the read_only_recommended of this ProtectionProperties.  # noqa: E501

        True if the document should be opened as read-only.  # noqa: E501

        :return: The read_only_recommended of this ProtectionProperties.  # noqa: E501
        :rtype: bool
        """
        return self._read_only_recommended

    @read_only_recommended.setter
    def read_only_recommended(self, read_only_recommended):
        """Sets the read_only_recommended of this ProtectionProperties.

        True if the document should be opened as read-only.  # noqa: E501

        :param read_only_recommended: The read_only_recommended of this ProtectionProperties.  # noqa: E501
        :type: bool
        """
        self._read_only_recommended = read_only_recommended

    @property
    def read_password(self):
        """Gets the read_password of this ProtectionProperties.  # noqa: E501

        Password for read protection.  # noqa: E501

        :return: The read_password of this ProtectionProperties.  # noqa: E501
        :rtype: str
        """
        return self._read_password

    @read_password.setter
    def read_password(self, read_password):
        """Sets the read_password of this ProtectionProperties.

        Password for read protection.  # noqa: E501

        :param read_password: The read_password of this ProtectionProperties.  # noqa: E501
        :type: str
        """
        self._read_password = read_password

    @property
    def write_password(self):
        """Gets the write_password of this ProtectionProperties.  # noqa: E501

        Password for write protection.  # noqa: E501

        :return: The write_password of this ProtectionProperties.  # noqa: E501
        :rtype: str
        """
        return self._write_password

    @write_password.setter
    def write_password(self, write_password):
        """Sets the write_password of this ProtectionProperties.

        Password for write protection.  # noqa: E501

        :param write_password: The write_password of this ProtectionProperties.  # noqa: E501
        :type: str
        """
        self._write_password = write_password

    @property
    def is_write_protected(self):
        """Gets the is_write_protected of this ProtectionProperties.  # noqa: E501

        Returns true if the presentation protected for editing.   # noqa: E501

        :return: The is_write_protected of this ProtectionProperties.  # noqa: E501
        :rtype: bool
        """
        return self._is_write_protected

    @is_write_protected.setter
    def is_write_protected(self, is_write_protected):
        """Sets the is_write_protected of this ProtectionProperties.

        Returns true if the presentation protected for editing.   # noqa: E501

        :param is_write_protected: The is_write_protected of this ProtectionProperties.  # noqa: E501
        :type: bool
        """
        self._is_write_protected = is_write_protected

    @property
    def is_encrypted(self):
        """Gets the is_encrypted of this ProtectionProperties.  # noqa: E501

        Returns true if the presentation protected for reading.   # noqa: E501

        :return: The is_encrypted of this ProtectionProperties.  # noqa: E501
        :rtype: bool
        """
        return self._is_encrypted

    @is_encrypted.setter
    def is_encrypted(self, is_encrypted):
        """Sets the is_encrypted of this ProtectionProperties.

        Returns true if the presentation protected for reading.   # noqa: E501

        :param is_encrypted: The is_encrypted of this ProtectionProperties.  # noqa: E501
        :type: bool
        """
        self._is_encrypted = is_encrypted

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProtectionProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class Hyperlink(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_disabled': 'bool',
        'action_type': 'str',
        'external_url': 'str',
        'target_slide_index': 'int',
        'target_frame': 'str',
        'tooltip': 'str',
        'history': 'bool',
        'highlight_click': 'bool',
        'stop_sound_on_click': 'bool',
        'color_source': 'str',
        'sound_base64': 'str'
    }

    attribute_map = {
        'is_disabled': 'isDisabled',
        'action_type': 'actionType',
        'external_url': 'externalUrl',
        'target_slide_index': 'targetSlideIndex',
        'target_frame': 'targetFrame',
        'tooltip': 'tooltip',
        'history': 'history',
        'highlight_click': 'highlightClick',
        'stop_sound_on_click': 'stopSoundOnClick',
        'color_source': 'colorSource',
        'sound_base64': 'soundBase64'
    }

    type_determiners = {
    }

    def __init__(self, is_disabled=None, action_type=None, external_url=None, target_slide_index=None, target_frame=None, tooltip=None, history=None, highlight_click=None, stop_sound_on_click=None, color_source=None, sound_base64=None):  # noqa: E501
        """Hyperlink - a model defined in Swagger"""  # noqa: E501

        self._is_disabled = None
        self._action_type = None
        self._external_url = None
        self._target_slide_index = None
        self._target_frame = None
        self._tooltip = None
        self._history = None
        self._highlight_click = None
        self._stop_sound_on_click = None
        self._color_source = None
        self._sound_base64 = None

        if is_disabled is not None:
            self.is_disabled = is_disabled
        self.action_type = action_type
        if external_url is not None:
            self.external_url = external_url
        if target_slide_index is not None:
            self.target_slide_index = target_slide_index
        if target_frame is not None:
            self.target_frame = target_frame
        if tooltip is not None:
            self.tooltip = tooltip
        if history is not None:
            self.history = history
        if highlight_click is not None:
            self.highlight_click = highlight_click
        if stop_sound_on_click is not None:
            self.stop_sound_on_click = stop_sound_on_click
        if color_source is not None:
            self.color_source = color_source
        if sound_base64 is not None:
            self.sound_base64 = sound_base64

    @property
    def is_disabled(self):
        """Gets the is_disabled of this Hyperlink.  # noqa: E501

        If true Hypelink is not applied.   # noqa: E501

        :return: The is_disabled of this Hyperlink.  # noqa: E501
        :rtype: bool
        """
        return self._is_disabled

    @is_disabled.setter
    def is_disabled(self, is_disabled):
        """Sets the is_disabled of this Hyperlink.

        If true Hypelink is not applied.   # noqa: E501

        :param is_disabled: The is_disabled of this Hyperlink.  # noqa: E501
        :type: bool
        """
        self._is_disabled = is_disabled

    @property
    def action_type(self):
        """Gets the action_type of this Hyperlink.  # noqa: E501

        Type of HyperLink action               # noqa: E501

        :return: The action_type of this Hyperlink.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this Hyperlink.

        Type of HyperLink action               # noqa: E501

        :param action_type: The action_type of this Hyperlink.  # noqa: E501
        :type: str
        """
        if action_type is not None:
            allowed_values = ["NoAction", "Hyperlink", "JumpFirstSlide", "JumpPreviousSlide", "JumpNextSlide", "JumpLastSlide", "JumpEndShow", "JumpLastViewedSlide", "JumpSpecificSlide", "StartCustomSlideShow", "OpenFile", "OpenPresentation", "StartStopMedia", "StartMacro", "StartProgram", "Unknown"]  # noqa: E501
            if action_type.isdigit():
                int_action_type = int(action_type)
                if int_action_type < 0 or int_action_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `action_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(action_type, allowed_values)
                    )
                self._action_type = allowed_values[int_action_type]
                return
            if action_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `action_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(action_type, allowed_values)
                )
        self._action_type = action_type

    @property
    def external_url(self):
        """Gets the external_url of this Hyperlink.  # noqa: E501

        Specifies the external URL  # noqa: E501

        :return: The external_url of this Hyperlink.  # noqa: E501
        :rtype: str
        """
        return self._external_url

    @external_url.setter
    def external_url(self, external_url):
        """Sets the external_url of this Hyperlink.

        Specifies the external URL  # noqa: E501

        :param external_url: The external_url of this Hyperlink.  # noqa: E501
        :type: str
        """
        self._external_url = external_url

    @property
    def target_slide_index(self):
        """Gets the target_slide_index of this Hyperlink.  # noqa: E501

        Index of the target slide  # noqa: E501

        :return: The target_slide_index of this Hyperlink.  # noqa: E501
        :rtype: int
        """
        return self._target_slide_index

    @target_slide_index.setter
    def target_slide_index(self, target_slide_index):
        """Sets the target_slide_index of this Hyperlink.

        Index of the target slide  # noqa: E501

        :param target_slide_index: The target_slide_index of this Hyperlink.  # noqa: E501
        :type: int
        """
        self._target_slide_index = target_slide_index

    @property
    def target_frame(self):
        """Gets the target_frame of this Hyperlink.  # noqa: E501

        Target frame  # noqa: E501

        :return: The target_frame of this Hyperlink.  # noqa: E501
        :rtype: str
        """
        return self._target_frame

    @target_frame.setter
    def target_frame(self, target_frame):
        """Sets the target_frame of this Hyperlink.

        Target frame  # noqa: E501

        :param target_frame: The target_frame of this Hyperlink.  # noqa: E501
        :type: str
        """
        self._target_frame = target_frame

    @property
    def tooltip(self):
        """Gets the tooltip of this Hyperlink.  # noqa: E501

        Hyperlink tooltip  # noqa: E501

        :return: The tooltip of this Hyperlink.  # noqa: E501
        :rtype: str
        """
        return self._tooltip

    @tooltip.setter
    def tooltip(self, tooltip):
        """Sets the tooltip of this Hyperlink.

        Hyperlink tooltip  # noqa: E501

        :param tooltip: The tooltip of this Hyperlink.  # noqa: E501
        :type: str
        """
        self._tooltip = tooltip

    @property
    def history(self):
        """Gets the history of this Hyperlink.  # noqa: E501

        Makes hyperlink viewed when it is invoked.               # noqa: E501

        :return: The history of this Hyperlink.  # noqa: E501
        :rtype: bool
        """
        return self._history

    @history.setter
    def history(self, history):
        """Sets the history of this Hyperlink.

        Makes hyperlink viewed when it is invoked.               # noqa: E501

        :param history: The history of this Hyperlink.  # noqa: E501
        :type: bool
        """
        self._history = history

    @property
    def highlight_click(self):
        """Gets the highlight_click of this Hyperlink.  # noqa: E501

        Determines whether the hyperlink should be highlighted on click.  # noqa: E501

        :return: The highlight_click of this Hyperlink.  # noqa: E501
        :rtype: bool
        """
        return self._highlight_click

    @highlight_click.setter
    def highlight_click(self, highlight_click):
        """Sets the highlight_click of this Hyperlink.

        Determines whether the hyperlink should be highlighted on click.  # noqa: E501

        :param highlight_click: The highlight_click of this Hyperlink.  # noqa: E501
        :type: bool
        """
        self._highlight_click = highlight_click

    @property
    def stop_sound_on_click(self):
        """Gets the stop_sound_on_click of this Hyperlink.  # noqa: E501

        Determines whether the sound should be stopped on hyperlink click  # noqa: E501

        :return: The stop_sound_on_click of this Hyperlink.  # noqa: E501
        :rtype: bool
        """
        return self._stop_sound_on_click

    @stop_sound_on_click.setter
    def stop_sound_on_click(self, stop_sound_on_click):
        """Sets the stop_sound_on_click of this Hyperlink.

        Determines whether the sound should be stopped on hyperlink click  # noqa: E501

        :param stop_sound_on_click: The stop_sound_on_click of this Hyperlink.  # noqa: E501
        :type: bool
        """
        self._stop_sound_on_click = stop_sound_on_click

    @property
    def color_source(self):
        """Gets the color_source of this Hyperlink.  # noqa: E501

        Represents the source of hyperlink color  # noqa: E501

        :return: The color_source of this Hyperlink.  # noqa: E501
        :rtype: str
        """
        return self._color_source

    @color_source.setter
    def color_source(self, color_source):
        """Sets the color_source of this Hyperlink.

        Represents the source of hyperlink color  # noqa: E501

        :param color_source: The color_source of this Hyperlink.  # noqa: E501
        :type: str
        """
        if color_source is not None:
            allowed_values = ["Styles", "PortionFormat"]  # noqa: E501
            if color_source.isdigit():
                int_color_source = int(color_source)
                if int_color_source < 0 or int_color_source >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `color_source` ({0}), must be one of {1}"  # noqa: E501
                        .format(color_source, allowed_values)
                    )
                self._color_source = allowed_values[int_color_source]
                return
            if color_source not in allowed_values:
                raise ValueError(
                    "Invalid value for `color_source` ({0}), must be one of {1}"  # noqa: E501
                    .format(color_source, allowed_values)
                )
        self._color_source = color_source

    @property
    def sound_base64(self):
        """Gets the sound_base64 of this Hyperlink.  # noqa: E501

        Audio data encoded in base64. Represents the playing sound of the hyperlink.   # noqa: E501

        :return: The sound_base64 of this Hyperlink.  # noqa: E501
        :rtype: str
        """
        return self._sound_base64

    @sound_base64.setter
    def sound_base64(self, sound_base64):
        """Sets the sound_base64 of this Hyperlink.

        Audio data encoded in base64. Represents the playing sound of the hyperlink.   # noqa: E501

        :param sound_base64: The sound_base64 of this Hyperlink.  # noqa: E501
        :type: str
        """
        self._sound_base64 = sound_base64

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Hyperlink):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class ThreeDFormat(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bevel_bottom': 'ShapeBevel',
        'bevel_top': 'ShapeBevel',
        'camera': 'Camera',
        'contour_color': 'str',
        'contour_width': 'float',
        'depth': 'float',
        'extrusion_color': 'str',
        'extrusion_height': 'float',
        'light_rig': 'LightRig',
        'material': 'str'
    }

    attribute_map = {
        'bevel_bottom': 'bevelBottom',
        'bevel_top': 'bevelTop',
        'camera': 'camera',
        'contour_color': 'contourColor',
        'contour_width': 'contourWidth',
        'depth': 'depth',
        'extrusion_color': 'extrusionColor',
        'extrusion_height': 'extrusionHeight',
        'light_rig': 'lightRig',
        'material': 'material'
    }

    type_determiners = {
    }

    def __init__(self, bevel_bottom=None, bevel_top=None, camera=None, contour_color=None, contour_width=None, depth=None, extrusion_color=None, extrusion_height=None, light_rig=None, material=None):  # noqa: E501
        """ThreeDFormat - a model defined in Swagger"""  # noqa: E501

        self._bevel_bottom = None
        self._bevel_top = None
        self._camera = None
        self._contour_color = None
        self._contour_width = None
        self._depth = None
        self._extrusion_color = None
        self._extrusion_height = None
        self._light_rig = None
        self._material = None

        if bevel_bottom is not None:
            self.bevel_bottom = bevel_bottom
        if bevel_top is not None:
            self.bevel_top = bevel_top
        if camera is not None:
            self.camera = camera
        if contour_color is not None:
            self.contour_color = contour_color
        if contour_width is not None:
            self.contour_width = contour_width
        if depth is not None:
            self.depth = depth
        if extrusion_color is not None:
            self.extrusion_color = extrusion_color
        if extrusion_height is not None:
            self.extrusion_height = extrusion_height
        if light_rig is not None:
            self.light_rig = light_rig
        if material is not None:
            self.material = material

    @property
    def bevel_bottom(self):
        """Gets the bevel_bottom of this ThreeDFormat.  # noqa: E501

        Type of a bottom 3D bevel.               # noqa: E501

        :return: The bevel_bottom of this ThreeDFormat.  # noqa: E501
        :rtype: ShapeBevel
        """
        return self._bevel_bottom

    @bevel_bottom.setter
    def bevel_bottom(self, bevel_bottom):
        """Sets the bevel_bottom of this ThreeDFormat.

        Type of a bottom 3D bevel.               # noqa: E501

        :param bevel_bottom: The bevel_bottom of this ThreeDFormat.  # noqa: E501
        :type: ShapeBevel
        """
        self._bevel_bottom = bevel_bottom

    @property
    def bevel_top(self):
        """Gets the bevel_top of this ThreeDFormat.  # noqa: E501

        Type of a top 3D bevel.               # noqa: E501

        :return: The bevel_top of this ThreeDFormat.  # noqa: E501
        :rtype: ShapeBevel
        """
        return self._bevel_top

    @bevel_top.setter
    def bevel_top(self, bevel_top):
        """Sets the bevel_top of this ThreeDFormat.

        Type of a top 3D bevel.               # noqa: E501

        :param bevel_top: The bevel_top of this ThreeDFormat.  # noqa: E501
        :type: ShapeBevel
        """
        self._bevel_top = bevel_top

    @property
    def camera(self):
        """Gets the camera of this ThreeDFormat.  # noqa: E501

        Camera  # noqa: E501

        :return: The camera of this ThreeDFormat.  # noqa: E501
        :rtype: Camera
        """
        return self._camera

    @camera.setter
    def camera(self, camera):
        """Sets the camera of this ThreeDFormat.

        Camera  # noqa: E501

        :param camera: The camera of this ThreeDFormat.  # noqa: E501
        :type: Camera
        """
        self._camera = camera

    @property
    def contour_color(self):
        """Gets the contour_color of this ThreeDFormat.  # noqa: E501

        Contour color  # noqa: E501

        :return: The contour_color of this ThreeDFormat.  # noqa: E501
        :rtype: str
        """
        return self._contour_color

    @contour_color.setter
    def contour_color(self, contour_color):
        """Sets the contour_color of this ThreeDFormat.

        Contour color  # noqa: E501

        :param contour_color: The contour_color of this ThreeDFormat.  # noqa: E501
        :type: str
        """
        self._contour_color = contour_color

    @property
    def contour_width(self):
        """Gets the contour_width of this ThreeDFormat.  # noqa: E501

        Contour width  # noqa: E501

        :return: The contour_width of this ThreeDFormat.  # noqa: E501
        :rtype: float
        """
        return self._contour_width

    @contour_width.setter
    def contour_width(self, contour_width):
        """Sets the contour_width of this ThreeDFormat.

        Contour width  # noqa: E501

        :param contour_width: The contour_width of this ThreeDFormat.  # noqa: E501
        :type: float
        """
        self._contour_width = contour_width

    @property
    def depth(self):
        """Gets the depth of this ThreeDFormat.  # noqa: E501

        Depth  # noqa: E501

        :return: The depth of this ThreeDFormat.  # noqa: E501
        :rtype: float
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this ThreeDFormat.

        Depth  # noqa: E501

        :param depth: The depth of this ThreeDFormat.  # noqa: E501
        :type: float
        """
        self._depth = depth

    @property
    def extrusion_color(self):
        """Gets the extrusion_color of this ThreeDFormat.  # noqa: E501

        Extrusion color  # noqa: E501

        :return: The extrusion_color of this ThreeDFormat.  # noqa: E501
        :rtype: str
        """
        return self._extrusion_color

    @extrusion_color.setter
    def extrusion_color(self, extrusion_color):
        """Sets the extrusion_color of this ThreeDFormat.

        Extrusion color  # noqa: E501

        :param extrusion_color: The extrusion_color of this ThreeDFormat.  # noqa: E501
        :type: str
        """
        self._extrusion_color = extrusion_color

    @property
    def extrusion_height(self):
        """Gets the extrusion_height of this ThreeDFormat.  # noqa: E501

        Extrusion height  # noqa: E501

        :return: The extrusion_height of this ThreeDFormat.  # noqa: E501
        :rtype: float
        """
        return self._extrusion_height

    @extrusion_height.setter
    def extrusion_height(self, extrusion_height):
        """Sets the extrusion_height of this ThreeDFormat.

        Extrusion height  # noqa: E501

        :param extrusion_height: The extrusion_height of this ThreeDFormat.  # noqa: E501
        :type: float
        """
        self._extrusion_height = extrusion_height

    @property
    def light_rig(self):
        """Gets the light_rig of this ThreeDFormat.  # noqa: E501

        Light rig  # noqa: E501

        :return: The light_rig of this ThreeDFormat.  # noqa: E501
        :rtype: LightRig
        """
        return self._light_rig

    @light_rig.setter
    def light_rig(self, light_rig):
        """Sets the light_rig of this ThreeDFormat.

        Light rig  # noqa: E501

        :param light_rig: The light_rig of this ThreeDFormat.  # noqa: E501
        :type: LightRig
        """
        self._light_rig = light_rig

    @property
    def material(self):
        """Gets the material of this ThreeDFormat.  # noqa: E501

        Material  # noqa: E501

        :return: The material of this ThreeDFormat.  # noqa: E501
        :rtype: str
        """
        return self._material

    @material.setter
    def material(self, material):
        """Sets the material of this ThreeDFormat.

        Material  # noqa: E501

        :param material: The material of this ThreeDFormat.  # noqa: E501
        :type: str
        """
        if material is not None:
            allowed_values = ["Clear", "DkEdge", "Flat", "LegacyMatte", "LegacyMetal", "LegacyPlastic", "LegacyWireframe", "Matte", "Metal", "Plastic", "Powder", "SoftEdge", "Softmetal", "TranslucentPowder", "WarmMatte", "NotDefined"]  # noqa: E501
            if material.isdigit():
                int_material = int(material)
                if int_material < 0 or int_material >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `material` ({0}), must be one of {1}"  # noqa: E501
                        .format(material, allowed_values)
                    )
                self._material = allowed_values[int_material]
                return
            if material not in allowed_values:
                raise ValueError(
                    "Invalid value for `material` ({0}), must be one of {1}"  # noqa: E501
                    .format(material, allowed_values)
                )
        self._material = material

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ThreeDFormat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.data_point import DataPoint

class OneValueChartDataPoint(DataPoint):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'three_d_format': 'ThreeDFormat',
        'line_format': 'LineFormat',
        'type': 'str',
        'value': 'float',
        'value_formula': 'str',
        'set_as_total': 'bool',
        'invert_if_negative': 'bool'
    }

    attribute_map = {
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'three_d_format': 'threeDFormat',
        'line_format': 'lineFormat',
        'type': 'type',
        'value': 'value',
        'value_formula': 'valueFormula',
        'set_as_total': 'setAsTotal',
        'invert_if_negative': 'invertIfNegative'
    }

    type_determiners = {
        'type': 'OneValue',
    }

    def __init__(self, fill_format=None, effect_format=None, three_d_format=None, line_format=None, type='OneValue', value=None, value_formula=None, set_as_total=None, invert_if_negative=None):  # noqa: E501
        """OneValueChartDataPoint - a model defined in Swagger"""  # noqa: E501
        super(OneValueChartDataPoint, self).__init__(fill_format, effect_format, three_d_format, line_format, type)

        self._value = None
        self._value_formula = None
        self._set_as_total = None
        self._invert_if_negative = None
        self.type = 'OneValue'

        if value is not None:
            self.value = value
        if value_formula is not None:
            self.value_formula = value_formula
        if set_as_total is not None:
            self.set_as_total = set_as_total
        if invert_if_negative is not None:
            self.invert_if_negative = invert_if_negative

    @property
    def value(self):
        """Gets the value of this OneValueChartDataPoint.  # noqa: E501

        Value.  # noqa: E501

        :return: The value of this OneValueChartDataPoint.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this OneValueChartDataPoint.

        Value.  # noqa: E501

        :param value: The value of this OneValueChartDataPoint.  # noqa: E501
        :type: float
        """
        self._value = value

    @property
    def value_formula(self):
        """Gets the value_formula of this OneValueChartDataPoint.  # noqa: E501

        Spreadsheet formula in A1-style.  # noqa: E501

        :return: The value_formula of this OneValueChartDataPoint.  # noqa: E501
        :rtype: str
        """
        return self._value_formula

    @value_formula.setter
    def value_formula(self, value_formula):
        """Sets the value_formula of this OneValueChartDataPoint.

        Spreadsheet formula in A1-style.  # noqa: E501

        :param value_formula: The value_formula of this OneValueChartDataPoint.  # noqa: E501
        :type: str
        """
        self._value_formula = value_formula

    @property
    def set_as_total(self):
        """Gets the set_as_total of this OneValueChartDataPoint.  # noqa: E501

        SetAsTotal. Applied to Waterfall data points only.  # noqa: E501

        :return: The set_as_total of this OneValueChartDataPoint.  # noqa: E501
        :rtype: bool
        """
        return self._set_as_total

    @set_as_total.setter
    def set_as_total(self, set_as_total):
        """Sets the set_as_total of this OneValueChartDataPoint.

        SetAsTotal. Applied to Waterfall data points only.  # noqa: E501

        :param set_as_total: The set_as_total of this OneValueChartDataPoint.  # noqa: E501
        :type: bool
        """
        self._set_as_total = set_as_total

    @property
    def invert_if_negative(self):
        """Gets the invert_if_negative of this OneValueChartDataPoint.  # noqa: E501

        True if the data point shall invert its colors if the value is negative. Applies to bar, column and bubble series.  # noqa: E501

        :return: The invert_if_negative of this OneValueChartDataPoint.  # noqa: E501
        :rtype: bool
        """
        return self._invert_if_negative

    @invert_if_negative.setter
    def invert_if_negative(self, invert_if_negative):
        """Sets the invert_if_negative of this OneValueChartDataPoint.

        True if the data point shall invert its colors if the value is negative. Applies to bar, column and bubble series.  # noqa: E501

        :param invert_if_negative: The invert_if_negative of this OneValueChartDataPoint.  # noqa: E501
        :type: bool
        """
        self._invert_if_negative = invert_if_negative

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OneValueChartDataPoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class TextFrameFormat(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'three_d_format': 'ThreeDFormat',
        'transform': 'str',
        'margin_left': 'float',
        'margin_right': 'float',
        'margin_top': 'float',
        'margin_bottom': 'float',
        'wrap_text': 'str',
        'anchoring_type': 'str',
        'center_text': 'str',
        'text_vertical_type': 'str',
        'autofit_type': 'str',
        'column_count': 'int',
        'column_spacing': 'float',
        'keep_text_flat': 'bool',
        'rotation_angle': 'float',
        'default_paragraph_format': 'ParagraphFormat'
    }

    attribute_map = {
        'three_d_format': 'threeDFormat',
        'transform': 'transform',
        'margin_left': 'marginLeft',
        'margin_right': 'marginRight',
        'margin_top': 'marginTop',
        'margin_bottom': 'marginBottom',
        'wrap_text': 'wrapText',
        'anchoring_type': 'anchoringType',
        'center_text': 'centerText',
        'text_vertical_type': 'textVerticalType',
        'autofit_type': 'autofitType',
        'column_count': 'columnCount',
        'column_spacing': 'columnSpacing',
        'keep_text_flat': 'keepTextFlat',
        'rotation_angle': 'rotationAngle',
        'default_paragraph_format': 'defaultParagraphFormat'
    }

    type_determiners = {
    }

    def __init__(self, three_d_format=None, transform=None, margin_left=None, margin_right=None, margin_top=None, margin_bottom=None, wrap_text=None, anchoring_type=None, center_text=None, text_vertical_type=None, autofit_type=None, column_count=None, column_spacing=None, keep_text_flat=None, rotation_angle=None, default_paragraph_format=None):  # noqa: E501
        """TextFrameFormat - a model defined in Swagger"""  # noqa: E501

        self._three_d_format = None
        self._transform = None
        self._margin_left = None
        self._margin_right = None
        self._margin_top = None
        self._margin_bottom = None
        self._wrap_text = None
        self._anchoring_type = None
        self._center_text = None
        self._text_vertical_type = None
        self._autofit_type = None
        self._column_count = None
        self._column_spacing = None
        self._keep_text_flat = None
        self._rotation_angle = None
        self._default_paragraph_format = None

        if three_d_format is not None:
            self.three_d_format = three_d_format
        if transform is not None:
            self.transform = transform
        if margin_left is not None:
            self.margin_left = margin_left
        if margin_right is not None:
            self.margin_right = margin_right
        if margin_top is not None:
            self.margin_top = margin_top
        if margin_bottom is not None:
            self.margin_bottom = margin_bottom
        if wrap_text is not None:
            self.wrap_text = wrap_text
        if anchoring_type is not None:
            self.anchoring_type = anchoring_type
        if center_text is not None:
            self.center_text = center_text
        if text_vertical_type is not None:
            self.text_vertical_type = text_vertical_type
        if autofit_type is not None:
            self.autofit_type = autofit_type
        if column_count is not None:
            self.column_count = column_count
        if column_spacing is not None:
            self.column_spacing = column_spacing
        if keep_text_flat is not None:
            self.keep_text_flat = keep_text_flat
        if rotation_angle is not None:
            self.rotation_angle = rotation_angle
        if default_paragraph_format is not None:
            self.default_paragraph_format = default_paragraph_format

    @property
    def three_d_format(self):
        """Gets the three_d_format of this TextFrameFormat.  # noqa: E501

        Represents 3d effect properties for a text.  # noqa: E501

        :return: The three_d_format of this TextFrameFormat.  # noqa: E501
        :rtype: ThreeDFormat
        """
        return self._three_d_format

    @three_d_format.setter
    def three_d_format(self, three_d_format):
        """Sets the three_d_format of this TextFrameFormat.

        Represents 3d effect properties for a text.  # noqa: E501

        :param three_d_format: The three_d_format of this TextFrameFormat.  # noqa: E501
        :type: ThreeDFormat
        """
        self._three_d_format = three_d_format

    @property
    def transform(self):
        """Gets the transform of this TextFrameFormat.  # noqa: E501

        Gets or sets text wrapping shape.  # noqa: E501

        :return: The transform of this TextFrameFormat.  # noqa: E501
        :rtype: str
        """
        return self._transform

    @transform.setter
    def transform(self, transform):
        """Sets the transform of this TextFrameFormat.

        Gets or sets text wrapping shape.  # noqa: E501

        :param transform: The transform of this TextFrameFormat.  # noqa: E501
        :type: str
        """
        if transform is not None:
            allowed_values = ["None", "Plain", "Stop", "Triangle", "TriangleInverted", "Chevron", "ChevronInverted", "RingInside", "RingOutside", "ArchUp", "ArchDown", "Circle", "Button", "ArchUpPour", "ArchDownPour", "CirclePour", "ButtonPour", "CurveUp", "CurveDown", "CanUp", "CanDown", "Wave1", "Wave2", "DoubleWave1", "Wave4", "Inflate", "Deflate", "InflateBottom", "DeflateBottom", "InflateTop", "DeflateTop", "DeflateInflate", "DeflateInflateDeflate", "FadeRight", "FadeLeft", "FadeUp", "FadeDown", "SlantUp", "SlantDown", "CascadeUp", "CascadeDown", "Custom", "NotDefined"]  # noqa: E501
            if transform.isdigit():
                int_transform = int(transform)
                if int_transform < 0 or int_transform >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `transform` ({0}), must be one of {1}"  # noqa: E501
                        .format(transform, allowed_values)
                    )
                self._transform = allowed_values[int_transform]
                return
            if transform not in allowed_values:
                raise ValueError(
                    "Invalid value for `transform` ({0}), must be one of {1}"  # noqa: E501
                    .format(transform, allowed_values)
                )
        self._transform = transform

    @property
    def margin_left(self):
        """Gets the margin_left of this TextFrameFormat.  # noqa: E501

        Left margin. Left margin.  # noqa: E501

        :return: The margin_left of this TextFrameFormat.  # noqa: E501
        :rtype: float
        """
        return self._margin_left

    @margin_left.setter
    def margin_left(self, margin_left):
        """Sets the margin_left of this TextFrameFormat.

        Left margin. Left margin.  # noqa: E501

        :param margin_left: The margin_left of this TextFrameFormat.  # noqa: E501
        :type: float
        """
        self._margin_left = margin_left

    @property
    def margin_right(self):
        """Gets the margin_right of this TextFrameFormat.  # noqa: E501

        Right margin.  # noqa: E501

        :return: The margin_right of this TextFrameFormat.  # noqa: E501
        :rtype: float
        """
        return self._margin_right

    @margin_right.setter
    def margin_right(self, margin_right):
        """Sets the margin_right of this TextFrameFormat.

        Right margin.  # noqa: E501

        :param margin_right: The margin_right of this TextFrameFormat.  # noqa: E501
        :type: float
        """
        self._margin_right = margin_right

    @property
    def margin_top(self):
        """Gets the margin_top of this TextFrameFormat.  # noqa: E501

        Top margin.  # noqa: E501

        :return: The margin_top of this TextFrameFormat.  # noqa: E501
        :rtype: float
        """
        return self._margin_top

    @margin_top.setter
    def margin_top(self, margin_top):
        """Sets the margin_top of this TextFrameFormat.

        Top margin.  # noqa: E501

        :param margin_top: The margin_top of this TextFrameFormat.  # noqa: E501
        :type: float
        """
        self._margin_top = margin_top

    @property
    def margin_bottom(self):
        """Gets the margin_bottom of this TextFrameFormat.  # noqa: E501

        Bottom margin.  # noqa: E501

        :return: The margin_bottom of this TextFrameFormat.  # noqa: E501
        :rtype: float
        """
        return self._margin_bottom

    @margin_bottom.setter
    def margin_bottom(self, margin_bottom):
        """Sets the margin_bottom of this TextFrameFormat.

        Bottom margin.  # noqa: E501

        :param margin_bottom: The margin_bottom of this TextFrameFormat.  # noqa: E501
        :type: float
        """
        self._margin_bottom = margin_bottom

    @property
    def wrap_text(self):
        """Gets the wrap_text of this TextFrameFormat.  # noqa: E501

        True if text is wrapped at TextFrame's margins.  # noqa: E501

        :return: The wrap_text of this TextFrameFormat.  # noqa: E501
        :rtype: str
        """
        return self._wrap_text

    @wrap_text.setter
    def wrap_text(self, wrap_text):
        """Sets the wrap_text of this TextFrameFormat.

        True if text is wrapped at TextFrame's margins.  # noqa: E501

        :param wrap_text: The wrap_text of this TextFrameFormat.  # noqa: E501
        :type: str
        """
        if wrap_text is not None:
            allowed_values = ["False", "True", "NotDefined"]  # noqa: E501
            if wrap_text.isdigit():
                int_wrap_text = int(wrap_text)
                if int_wrap_text < 0 or int_wrap_text >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `wrap_text` ({0}), must be one of {1}"  # noqa: E501
                        .format(wrap_text, allowed_values)
                    )
                self._wrap_text = allowed_values[int_wrap_text]
                return
            if wrap_text not in allowed_values:
                raise ValueError(
                    "Invalid value for `wrap_text` ({0}), must be one of {1}"  # noqa: E501
                    .format(wrap_text, allowed_values)
                )
        self._wrap_text = wrap_text

    @property
    def anchoring_type(self):
        """Gets the anchoring_type of this TextFrameFormat.  # noqa: E501

        Returns or sets vertical anchor text in a TextFrame.  # noqa: E501

        :return: The anchoring_type of this TextFrameFormat.  # noqa: E501
        :rtype: str
        """
        return self._anchoring_type

    @anchoring_type.setter
    def anchoring_type(self, anchoring_type):
        """Sets the anchoring_type of this TextFrameFormat.

        Returns or sets vertical anchor text in a TextFrame.  # noqa: E501

        :param anchoring_type: The anchoring_type of this TextFrameFormat.  # noqa: E501
        :type: str
        """
        if anchoring_type is not None:
            allowed_values = ["Top", "Center", "Bottom", "Justified", "Distributed", "NotDefined"]  # noqa: E501
            if anchoring_type.isdigit():
                int_anchoring_type = int(anchoring_type)
                if int_anchoring_type < 0 or int_anchoring_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `anchoring_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(anchoring_type, allowed_values)
                    )
                self._anchoring_type = allowed_values[int_anchoring_type]
                return
            if anchoring_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `anchoring_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(anchoring_type, allowed_values)
                )
        self._anchoring_type = anchoring_type

    @property
    def center_text(self):
        """Gets the center_text of this TextFrameFormat.  # noqa: E501

        If True then text should be centered in box horizontally.  # noqa: E501

        :return: The center_text of this TextFrameFormat.  # noqa: E501
        :rtype: str
        """
        return self._center_text

    @center_text.setter
    def center_text(self, center_text):
        """Sets the center_text of this TextFrameFormat.

        If True then text should be centered in box horizontally.  # noqa: E501

        :param center_text: The center_text of this TextFrameFormat.  # noqa: E501
        :type: str
        """
        if center_text is not None:
            allowed_values = ["False", "True", "NotDefined"]  # noqa: E501
            if center_text.isdigit():
                int_center_text = int(center_text)
                if int_center_text < 0 or int_center_text >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `center_text` ({0}), must be one of {1}"  # noqa: E501
                        .format(center_text, allowed_values)
                    )
                self._center_text = allowed_values[int_center_text]
                return
            if center_text not in allowed_values:
                raise ValueError(
                    "Invalid value for `center_text` ({0}), must be one of {1}"  # noqa: E501
                    .format(center_text, allowed_values)
                )
        self._center_text = center_text

    @property
    def text_vertical_type(self):
        """Gets the text_vertical_type of this TextFrameFormat.  # noqa: E501

        Determines text orientation. The resulted value of visual text rotation summarized from this property and custom angle in property RotationAngle.  # noqa: E501

        :return: The text_vertical_type of this TextFrameFormat.  # noqa: E501
        :rtype: str
        """
        return self._text_vertical_type

    @text_vertical_type.setter
    def text_vertical_type(self, text_vertical_type):
        """Sets the text_vertical_type of this TextFrameFormat.

        Determines text orientation. The resulted value of visual text rotation summarized from this property and custom angle in property RotationAngle.  # noqa: E501

        :param text_vertical_type: The text_vertical_type of this TextFrameFormat.  # noqa: E501
        :type: str
        """
        if text_vertical_type is not None:
            allowed_values = ["Horizontal", "Vertical", "Vertical270", "WordArtVertical", "EastAsianVertical", "MongolianVertical", "WordArtVerticalRightToLeft", "NotDefined"]  # noqa: E501
            if text_vertical_type.isdigit():
                int_text_vertical_type = int(text_vertical_type)
                if int_text_vertical_type < 0 or int_text_vertical_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `text_vertical_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(text_vertical_type, allowed_values)
                    )
                self._text_vertical_type = allowed_values[int_text_vertical_type]
                return
            if text_vertical_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `text_vertical_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(text_vertical_type, allowed_values)
                )
        self._text_vertical_type = text_vertical_type

    @property
    def autofit_type(self):
        """Gets the autofit_type of this TextFrameFormat.  # noqa: E501

        Returns or sets text's auto-fit mode.  # noqa: E501

        :return: The autofit_type of this TextFrameFormat.  # noqa: E501
        :rtype: str
        """
        return self._autofit_type

    @autofit_type.setter
    def autofit_type(self, autofit_type):
        """Sets the autofit_type of this TextFrameFormat.

        Returns or sets text's auto-fit mode.  # noqa: E501

        :param autofit_type: The autofit_type of this TextFrameFormat.  # noqa: E501
        :type: str
        """
        if autofit_type is not None:
            allowed_values = ["None", "Normal", "Shape", "NotDefined"]  # noqa: E501
            if autofit_type.isdigit():
                int_autofit_type = int(autofit_type)
                if int_autofit_type < 0 or int_autofit_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `autofit_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(autofit_type, allowed_values)
                    )
                self._autofit_type = allowed_values[int_autofit_type]
                return
            if autofit_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `autofit_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(autofit_type, allowed_values)
                )
        self._autofit_type = autofit_type

    @property
    def column_count(self):
        """Gets the column_count of this TextFrameFormat.  # noqa: E501

        Returns or sets number of columns in the text area. This value must be a positive number. Otherwise, the value will be set to zero.  Value 0 means undefined value.  # noqa: E501

        :return: The column_count of this TextFrameFormat.  # noqa: E501
        :rtype: int
        """
        return self._column_count

    @column_count.setter
    def column_count(self, column_count):
        """Sets the column_count of this TextFrameFormat.

        Returns or sets number of columns in the text area. This value must be a positive number. Otherwise, the value will be set to zero.  Value 0 means undefined value.  # noqa: E501

        :param column_count: The column_count of this TextFrameFormat.  # noqa: E501
        :type: int
        """
        self._column_count = column_count

    @property
    def column_spacing(self):
        """Gets the column_spacing of this TextFrameFormat.  # noqa: E501

        Returns or sets the space between text columns in the text area (in points). This should only apply  when there is more than 1 column present. This value must be a positive number. Otherwise, the value will be set to zero.   # noqa: E501

        :return: The column_spacing of this TextFrameFormat.  # noqa: E501
        :rtype: float
        """
        return self._column_spacing

    @column_spacing.setter
    def column_spacing(self, column_spacing):
        """Sets the column_spacing of this TextFrameFormat.

        Returns or sets the space between text columns in the text area (in points). This should only apply  when there is more than 1 column present. This value must be a positive number. Otherwise, the value will be set to zero.   # noqa: E501

        :param column_spacing: The column_spacing of this TextFrameFormat.  # noqa: E501
        :type: float
        """
        self._column_spacing = column_spacing

    @property
    def keep_text_flat(self):
        """Gets the keep_text_flat of this TextFrameFormat.  # noqa: E501

        Returns or set keeping text out of 3D scene entirely.  # noqa: E501

        :return: The keep_text_flat of this TextFrameFormat.  # noqa: E501
        :rtype: bool
        """
        return self._keep_text_flat

    @keep_text_flat.setter
    def keep_text_flat(self, keep_text_flat):
        """Sets the keep_text_flat of this TextFrameFormat.

        Returns or set keeping text out of 3D scene entirely.  # noqa: E501

        :param keep_text_flat: The keep_text_flat of this TextFrameFormat.  # noqa: E501
        :type: bool
        """
        self._keep_text_flat = keep_text_flat

    @property
    def rotation_angle(self):
        """Gets the rotation_angle of this TextFrameFormat.  # noqa: E501

        Specifies the custom rotation that is being applied to the text within the bounding box.  # noqa: E501

        :return: The rotation_angle of this TextFrameFormat.  # noqa: E501
        :rtype: float
        """
        return self._rotation_angle

    @rotation_angle.setter
    def rotation_angle(self, rotation_angle):
        """Sets the rotation_angle of this TextFrameFormat.

        Specifies the custom rotation that is being applied to the text within the bounding box.  # noqa: E501

        :param rotation_angle: The rotation_angle of this TextFrameFormat.  # noqa: E501
        :type: float
        """
        self._rotation_angle = rotation_angle

    @property
    def default_paragraph_format(self):
        """Gets the default_paragraph_format of this TextFrameFormat.  # noqa: E501

        Default portion format.  # noqa: E501

        :return: The default_paragraph_format of this TextFrameFormat.  # noqa: E501
        :rtype: ParagraphFormat
        """
        return self._default_paragraph_format

    @default_paragraph_format.setter
    def default_paragraph_format(self, default_paragraph_format):
        """Sets the default_paragraph_format of this TextFrameFormat.

        Default portion format.  # noqa: E501

        :param default_paragraph_format: The default_paragraph_format of this TextFrameFormat.  # noqa: E501
        :type: ParagraphFormat
        """
        self._default_paragraph_format = default_paragraph_format

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TextFrameFormat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.resource_base import ResourceBase

class SlideShowProperties(ResourceBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'loop': 'bool',
        'start_slide': 'int',
        'end_slide': 'int',
        'pen_color': 'str',
        'show_animation': 'bool',
        'show_narration': 'bool',
        'use_timings': 'bool',
        'slide_show_type': 'str',
        'show_scrollbar': 'bool'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'loop': 'loop',
        'start_slide': 'startSlide',
        'end_slide': 'endSlide',
        'pen_color': 'penColor',
        'show_animation': 'showAnimation',
        'show_narration': 'showNarration',
        'use_timings': 'useTimings',
        'slide_show_type': 'slideShowType',
        'show_scrollbar': 'showScrollbar'
    }

    type_determiners = {
    }

    def __init__(self, self_uri=None, alternate_links=None, loop=None, start_slide=None, end_slide=None, pen_color=None, show_animation=None, show_narration=None, use_timings=None, slide_show_type=None, show_scrollbar=None):  # noqa: E501
        """SlideShowProperties - a model defined in Swagger"""  # noqa: E501
        super(SlideShowProperties, self).__init__(self_uri, alternate_links)

        self._loop = None
        self._start_slide = None
        self._end_slide = None
        self._pen_color = None
        self._show_animation = None
        self._show_narration = None
        self._use_timings = None
        self._slide_show_type = None
        self._show_scrollbar = None

        if loop is not None:
            self.loop = loop
        if start_slide is not None:
            self.start_slide = start_slide
        if end_slide is not None:
            self.end_slide = end_slide
        if pen_color is not None:
            self.pen_color = pen_color
        if show_animation is not None:
            self.show_animation = show_animation
        if show_narration is not None:
            self.show_narration = show_narration
        if use_timings is not None:
            self.use_timings = use_timings
        if slide_show_type is not None:
            self.slide_show_type = slide_show_type
        if show_scrollbar is not None:
            self.show_scrollbar = show_scrollbar

    @property
    def loop(self):
        """Gets the loop of this SlideShowProperties.  # noqa: E501

        Loop slide show.  # noqa: E501

        :return: The loop of this SlideShowProperties.  # noqa: E501
        :rtype: bool
        """
        return self._loop

    @loop.setter
    def loop(self, loop):
        """Sets the loop of this SlideShowProperties.

        Loop slide show.  # noqa: E501

        :param loop: The loop of this SlideShowProperties.  # noqa: E501
        :type: bool
        """
        self._loop = loop

    @property
    def start_slide(self):
        """Gets the start_slide of this SlideShowProperties.  # noqa: E501

        Start slide in the slide show.  # noqa: E501

        :return: The start_slide of this SlideShowProperties.  # noqa: E501
        :rtype: int
        """
        return self._start_slide

    @start_slide.setter
    def start_slide(self, start_slide):
        """Sets the start_slide of this SlideShowProperties.

        Start slide in the slide show.  # noqa: E501

        :param start_slide: The start_slide of this SlideShowProperties.  # noqa: E501
        :type: int
        """
        self._start_slide = start_slide

    @property
    def end_slide(self):
        """Gets the end_slide of this SlideShowProperties.  # noqa: E501

        End slides in the slide show.  # noqa: E501

        :return: The end_slide of this SlideShowProperties.  # noqa: E501
        :rtype: int
        """
        return self._end_slide

    @end_slide.setter
    def end_slide(self, end_slide):
        """Sets the end_slide of this SlideShowProperties.

        End slides in the slide show.  # noqa: E501

        :param end_slide: The end_slide of this SlideShowProperties.  # noqa: E501
        :type: int
        """
        self._end_slide = end_slide

    @property
    def pen_color(self):
        """Gets the pen_color of this SlideShowProperties.  # noqa: E501

        Pen color.  # noqa: E501

        :return: The pen_color of this SlideShowProperties.  # noqa: E501
        :rtype: str
        """
        return self._pen_color

    @pen_color.setter
    def pen_color(self, pen_color):
        """Sets the pen_color of this SlideShowProperties.

        Pen color.  # noqa: E501

        :param pen_color: The pen_color of this SlideShowProperties.  # noqa: E501
        :type: str
        """
        self._pen_color = pen_color

    @property
    def show_animation(self):
        """Gets the show_animation of this SlideShowProperties.  # noqa: E501

        Show animation.  # noqa: E501

        :return: The show_animation of this SlideShowProperties.  # noqa: E501
        :rtype: bool
        """
        return self._show_animation

    @show_animation.setter
    def show_animation(self, show_animation):
        """Sets the show_animation of this SlideShowProperties.

        Show animation.  # noqa: E501

        :param show_animation: The show_animation of this SlideShowProperties.  # noqa: E501
        :type: bool
        """
        self._show_animation = show_animation

    @property
    def show_narration(self):
        """Gets the show_narration of this SlideShowProperties.  # noqa: E501

        Show narrration.  # noqa: E501

        :return: The show_narration of this SlideShowProperties.  # noqa: E501
        :rtype: bool
        """
        return self._show_narration

    @show_narration.setter
    def show_narration(self, show_narration):
        """Sets the show_narration of this SlideShowProperties.

        Show narrration.  # noqa: E501

        :param show_narration: The show_narration of this SlideShowProperties.  # noqa: E501
        :type: bool
        """
        self._show_narration = show_narration

    @property
    def use_timings(self):
        """Gets the use_timings of this SlideShowProperties.  # noqa: E501

        Use timings.  # noqa: E501

        :return: The use_timings of this SlideShowProperties.  # noqa: E501
        :rtype: bool
        """
        return self._use_timings

    @use_timings.setter
    def use_timings(self, use_timings):
        """Sets the use_timings of this SlideShowProperties.

        Use timings.  # noqa: E501

        :param use_timings: The use_timings of this SlideShowProperties.  # noqa: E501
        :type: bool
        """
        self._use_timings = use_timings

    @property
    def slide_show_type(self):
        """Gets the slide_show_type of this SlideShowProperties.  # noqa: E501

        Slide show type.  # noqa: E501

        :return: The slide_show_type of this SlideShowProperties.  # noqa: E501
        :rtype: str
        """
        return self._slide_show_type

    @slide_show_type.setter
    def slide_show_type(self, slide_show_type):
        """Sets the slide_show_type of this SlideShowProperties.

        Slide show type.  # noqa: E501

        :param slide_show_type: The slide_show_type of this SlideShowProperties.  # noqa: E501
        :type: str
        """
        if slide_show_type is not None:
            allowed_values = ["BrowsedAtKiosk", "BrowsedByIndividual", "PresentedBySpeaker"]  # noqa: E501
            if slide_show_type.isdigit():
                int_slide_show_type = int(slide_show_type)
                if int_slide_show_type < 0 or int_slide_show_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `slide_show_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(slide_show_type, allowed_values)
                    )
                self._slide_show_type = allowed_values[int_slide_show_type]
                return
            if slide_show_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `slide_show_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(slide_show_type, allowed_values)
                )
        self._slide_show_type = slide_show_type

    @property
    def show_scrollbar(self):
        """Gets the show_scrollbar of this SlideShowProperties.  # noqa: E501

        Show scroll bar. Applied with BrowsedByIndividual slide show type.  # noqa: E501

        :return: The show_scrollbar of this SlideShowProperties.  # noqa: E501
        :rtype: bool
        """
        return self._show_scrollbar

    @show_scrollbar.setter
    def show_scrollbar(self, show_scrollbar):
        """Sets the show_scrollbar of this SlideShowProperties.

        Show scroll bar. Applied with BrowsedByIndividual slide show type.  # noqa: E501

        :param show_scrollbar: The show_scrollbar of this SlideShowProperties.  # noqa: E501
        :type: bool
        """
        self._show_scrollbar = show_scrollbar

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SlideShowProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.math_element import MathElement

class NaryOperatorElement(MathElement):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'base': 'MathElement',
        'subscript': 'MathElement',
        'superscript': 'MathElement',
        'operator': 'str',
        'limit_location': 'str',
        'grow_to_match_operand_height': 'bool',
        'hide_subscript': 'bool',
        'hide_superscript': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'base': 'base',
        'subscript': 'subscript',
        'superscript': 'superscript',
        'operator': 'operator',
        'limit_location': 'limitLocation',
        'grow_to_match_operand_height': 'growToMatchOperandHeight',
        'hide_subscript': 'hideSubscript',
        'hide_superscript': 'hideSuperscript'
    }

    type_determiners = {
        'type': 'NaryOperator',
    }

    def __init__(self, type='NaryOperator', base=None, subscript=None, superscript=None, operator=None, limit_location=None, grow_to_match_operand_height=None, hide_subscript=None, hide_superscript=None):  # noqa: E501
        """NaryOperatorElement - a model defined in Swagger"""  # noqa: E501
        super(NaryOperatorElement, self).__init__(type)

        self._base = None
        self._subscript = None
        self._superscript = None
        self._operator = None
        self._limit_location = None
        self._grow_to_match_operand_height = None
        self._hide_subscript = None
        self._hide_superscript = None
        self.type = 'NaryOperator'

        if base is not None:
            self.base = base
        if subscript is not None:
            self.subscript = subscript
        if superscript is not None:
            self.superscript = superscript
        if operator is not None:
            self.operator = operator
        if limit_location is not None:
            self.limit_location = limit_location
        if grow_to_match_operand_height is not None:
            self.grow_to_match_operand_height = grow_to_match_operand_height
        if hide_subscript is not None:
            self.hide_subscript = hide_subscript
        if hide_superscript is not None:
            self.hide_superscript = hide_superscript

    @property
    def base(self):
        """Gets the base of this NaryOperatorElement.  # noqa: E501

        Base argument  # noqa: E501

        :return: The base of this NaryOperatorElement.  # noqa: E501
        :rtype: MathElement
        """
        return self._base

    @base.setter
    def base(self, base):
        """Sets the base of this NaryOperatorElement.

        Base argument  # noqa: E501

        :param base: The base of this NaryOperatorElement.  # noqa: E501
        :type: MathElement
        """
        self._base = base

    @property
    def subscript(self):
        """Gets the subscript of this NaryOperatorElement.  # noqa: E501

        Subscript argument  # noqa: E501

        :return: The subscript of this NaryOperatorElement.  # noqa: E501
        :rtype: MathElement
        """
        return self._subscript

    @subscript.setter
    def subscript(self, subscript):
        """Sets the subscript of this NaryOperatorElement.

        Subscript argument  # noqa: E501

        :param subscript: The subscript of this NaryOperatorElement.  # noqa: E501
        :type: MathElement
        """
        self._subscript = subscript

    @property
    def superscript(self):
        """Gets the superscript of this NaryOperatorElement.  # noqa: E501

        Superscript argument  # noqa: E501

        :return: The superscript of this NaryOperatorElement.  # noqa: E501
        :rtype: MathElement
        """
        return self._superscript

    @superscript.setter
    def superscript(self, superscript):
        """Sets the superscript of this NaryOperatorElement.

        Superscript argument  # noqa: E501

        :param superscript: The superscript of this NaryOperatorElement.  # noqa: E501
        :type: MathElement
        """
        self._superscript = superscript

    @property
    def operator(self):
        """Gets the operator of this NaryOperatorElement.  # noqa: E501

        Nary Operator Character  # noqa: E501

        :return: The operator of this NaryOperatorElement.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this NaryOperatorElement.

        Nary Operator Character  # noqa: E501

        :param operator: The operator of this NaryOperatorElement.  # noqa: E501
        :type: str
        """
        self._operator = operator

    @property
    def limit_location(self):
        """Gets the limit_location of this NaryOperatorElement.  # noqa: E501

        The location of limits (subscript and superscript)  # noqa: E501

        :return: The limit_location of this NaryOperatorElement.  # noqa: E501
        :rtype: str
        """
        return self._limit_location

    @limit_location.setter
    def limit_location(self, limit_location):
        """Sets the limit_location of this NaryOperatorElement.

        The location of limits (subscript and superscript)  # noqa: E501

        :param limit_location: The limit_location of this NaryOperatorElement.  # noqa: E501
        :type: str
        """
        if limit_location is not None:
            allowed_values = ["NotDefined", "UnderOver", "SubscriptSuperscript"]  # noqa: E501
            if limit_location.isdigit():
                int_limit_location = int(limit_location)
                if int_limit_location < 0 or int_limit_location >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `limit_location` ({0}), must be one of {1}"  # noqa: E501
                        .format(limit_location, allowed_values)
                    )
                self._limit_location = allowed_values[int_limit_location]
                return
            if limit_location not in allowed_values:
                raise ValueError(
                    "Invalid value for `limit_location` ({0}), must be one of {1}"  # noqa: E501
                    .format(limit_location, allowed_values)
                )
        self._limit_location = limit_location

    @property
    def grow_to_match_operand_height(self):
        """Gets the grow_to_match_operand_height of this NaryOperatorElement.  # noqa: E501

        Operator Character grows vertically to match its operand height  # noqa: E501

        :return: The grow_to_match_operand_height of this NaryOperatorElement.  # noqa: E501
        :rtype: bool
        """
        return self._grow_to_match_operand_height

    @grow_to_match_operand_height.setter
    def grow_to_match_operand_height(self, grow_to_match_operand_height):
        """Sets the grow_to_match_operand_height of this NaryOperatorElement.

        Operator Character grows vertically to match its operand height  # noqa: E501

        :param grow_to_match_operand_height: The grow_to_match_operand_height of this NaryOperatorElement.  # noqa: E501
        :type: bool
        """
        self._grow_to_match_operand_height = grow_to_match_operand_height

    @property
    def hide_subscript(self):
        """Gets the hide_subscript of this NaryOperatorElement.  # noqa: E501

        Hide Subscript  # noqa: E501

        :return: The hide_subscript of this NaryOperatorElement.  # noqa: E501
        :rtype: bool
        """
        return self._hide_subscript

    @hide_subscript.setter
    def hide_subscript(self, hide_subscript):
        """Sets the hide_subscript of this NaryOperatorElement.

        Hide Subscript  # noqa: E501

        :param hide_subscript: The hide_subscript of this NaryOperatorElement.  # noqa: E501
        :type: bool
        """
        self._hide_subscript = hide_subscript

    @property
    def hide_superscript(self):
        """Gets the hide_superscript of this NaryOperatorElement.  # noqa: E501

        Hide Superscript  # noqa: E501

        :return: The hide_superscript of this NaryOperatorElement.  # noqa: E501
        :rtype: bool
        """
        return self._hide_superscript

    @hide_superscript.setter
    def hide_superscript(self, hide_superscript):
        """Sets the hide_superscript of this NaryOperatorElement.

        Hide Superscript  # noqa: E501

        :param hide_superscript: The hide_superscript of this NaryOperatorElement.  # noqa: E501
        :type: bool
        """
        self._hide_superscript = hide_superscript

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NaryOperatorElement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
